@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -21,7 +21,7 @@ use Composer\Package\AliasPackage;
  */
 class MarkAliasInstalledOperation extends SolverOperation implements OperationInterface
 {
-    const TYPE = 'markAliasInstalled';
+    protected const TYPE = 'markAliasInstalled';
 
     /**
      * @var AliasPackage
@@ -35,10 +35,8 @@ class MarkAliasInstalledOperation extends SolverOperation implements OperationIn
 
     /**
      * Returns package instance.
-     *
-     * @return AliasPackage
      */
-    public function getPackage()
+    public function getPackage(): AliasPackage
     {
         return $this->package;
     }
@@ -46,7 +44,7 @@ class MarkAliasInstalledOperation extends SolverOperation implements OperationIn
     /**
      * @inheritDoc
      */
-    public function show($lock)
+    public function show($lock): string
     {
         return 'Marking <info>'.$this->package->getPrettyName().'</info> (<comment>'.$this->package->getFullPrettyVersion().'</comment>) as installed, alias of <info>'.$this->package->getAliasOf()->getPrettyName().'</info> (<comment>'.$this->package->getAliasOf()->getFullPrettyVersion().'</comment>)';
     }
