@@ -40,7 +40,7 @@ class PoolBuilder
 {
     /**
      * @var int[]
-     * @phpstan-var array<string, BasePackage::STABILITY_*>
+     * @phpstan-var array<key-of<BasePackage::STABILITIES>, BasePackage::STABILITY_*>
      */
     private $acceptableStabilities;
     /**
@@ -95,7 +95,7 @@ class PoolBuilder
      */
     private $loadedPerRepo = [];
     /**
-     * @var BasePackage[]
+     * @var array<int, BasePackage>
      */
     private $packages = [];
     /**
@@ -106,6 +106,10 @@ class PoolBuilder
     private $updateAllowList = [];
     /** @var array<string, array<PackageInterface>> */
     private $skippedLoad = [];
+    /** @var list<string> */
+    private $ignoredTypes = [];
+    /** @var list<string>|null */
+    private $allowedTypes = null;
 
     /**
      * If provided, only these package names are loaded
@@ -149,7 +153,7 @@ class PoolBuilder
 
     /**
      * @param int[] $acceptableStabilities array of stability => BasePackage::STABILITY_* value
-     * @phpstan-param array<string, BasePackage::STABILITY_*> $acceptableStabilities
+     * @phpstan-param array<key-of<BasePackage::STABILITIES>, BasePackage::STABILITY_*> $acceptableStabilities
      * @param int[] $stabilityFlags an array of package name => BasePackage::STABILITY_* value
      * @phpstan-param array<string, BasePackage::STABILITY_*> $stabilityFlags
      * @param array[] $rootAliases
@@ -170,6 +174,26 @@ class PoolBuilder
         $this->temporaryConstraints = $temporaryConstraints;
     }
 
+    /**
+     * Packages of those types are ignored
+     *
+     * @param list<string> $types
+     */
+    public function setIgnoredTypes(array $types): void
+    {
+        $this->ignoredTypes = $types;
+    }
+
+    /**
+     * Only packages of those types are allowed if set to non-null
+     *
+     * @param list<string>|null $types
+     */
+    public function setAllowedTypes(?array $types): void
+    {
+        $this->allowedTypes = $types;
+    }
+
     /**
      * @param RepositoryInterface[] $repositories
      */
@@ -177,10 +201,14 @@ class PoolBuilder
     {
         $this->restrictedPackagesList = $request->getRestrictedPackages() !== null ? array_flip($request->getRestrictedPackages()) : null;
 
-        if ($request->getUpdateAllowList()) {
+        if (\count($request->getUpdateAllowList()) > 0) {
             $this->updateAllowList = $request->getUpdateAllowList();
             $this->warnAboutNonMatchingUpdateAllowList($request);
 
+            if (null === $request->getLockedRepository()) {
+                throw new \LogicException('No lock repo present and yet a partial update was requested.');
+            }
+
             foreach ($request->getLockedRepository()->getPackages() as $lockedPackage) {
                 if (!$this->isUpdateAllowed($lockedPackage)) {
                     // remember which packages we skipped loading remote content for in this partial update
@@ -247,7 +275,7 @@ class PoolBuilder
             }
         }
 
-        while (!empty($this->packagesToLoad)) {
+        while (\count($this->packagesToLoad) > 0) {
             $this->loadPackagesMarkedForLoading($request, $repositories);
         }
 
@@ -279,7 +307,7 @@ class PoolBuilder
             }
         }
 
-        if ($this->eventDispatcher) {
+        if ($this->eventDispatcher !== null) {
             $prePoolCreateEvent = new PrePoolCreateEvent(
                 PluginEvents::PRE_POOL_CREATE,
                 $repositories,
@@ -389,7 +417,7 @@ class PoolBuilder
         $this->packagesToLoad = [];
 
         foreach ($repositories as $repoIndex => $repository) {
-            if (empty($packageBatch)) {
+            if (0 === \count($packageBatch)) {
                 break;
             }
 
@@ -406,6 +434,10 @@ class PoolBuilder
             }
             foreach ($result['packages'] as $package) {
                 $this->loadedPerRepo[$repoIndex][$package->getName()][$package->getVersion()] = $package;
+
+                if (in_array($package->getType(), $this->ignoredTypes, true) || ($this->allowedTypes !== null && !in_array($package->getType(), $this->allowedTypes, true))) {
+                    continue;
+                }
                 $this->loadPackage($request, $repositories, $package, !isset($this->pathRepoUnlocked[$package->getName()]));
             }
         }
@@ -471,7 +503,7 @@ class PoolBuilder
                 if ($propagateUpdate && $request->getUpdateAllowTransitiveDependencies()) {
                     $skippedRootRequires = $this->getSkippedRootRequires($request, $require);
 
-                    if ($request->getUpdateAllowTransitiveRootDependencies() || !$skippedRootRequires) {
+                    if ($request->getUpdateAllowTransitiveRootDependencies() || 0 === \count($skippedRootRequires)) {
                         $this->unlockPackage($request, $repositories, $require);
                         $this->markPackageNameForLoading($request, $require, $linkConstraint);
                     } else {
@@ -500,7 +532,7 @@ class PoolBuilder
                 if (isset($this->loadedPackages[$replace], $this->skippedLoad[$replace])) {
                     $skippedRootRequires = $this->getSkippedRootRequires($request, $replace);
 
-                    if ($request->getUpdateAllowTransitiveRootDependencies() || !$skippedRootRequires) {
+                    if ($request->getUpdateAllowTransitiveRootDependencies() || 0 === \count($skippedRootRequires)) {
                         $this->unlockPackage($request, $repositories, $replace);
                         // the replaced package only needs to be loaded if something else requires it
                         $this->markPackageNameForLoadingIfRequired($request, $replace);
@@ -587,7 +619,13 @@ class PoolBuilder
 
     private function warnAboutNonMatchingUpdateAllowList(Request $request): void
     {
+        if (null === $request->getLockedRepository()) {
+            throw new \LogicException('No lock repo present and yet a partial update was requested.');
+        }
+
         foreach ($this->updateAllowList as $pattern) {
+            $matchedPlatformPackage = false;
+
             $patternRegexp = BasePackage::packageNameToRegexp($pattern);
             // update pattern matches a locked package? => all good
             foreach ($request->getLockedRepository()->getPackages() as $package) {
@@ -598,10 +636,16 @@ class PoolBuilder
             // update pattern matches a root require? => all good, probably a new package
             foreach ($request->getRequires() as $packageName => $constraint) {
                 if (Preg::isMatch($patternRegexp, $packageName)) {
+                    if (PlatformRepository::isPlatformPackage($packageName)) {
+                        $matchedPlatformPackage = true;
+                        continue;
+                    }
                     continue 2;
                 }
             }
-            if (strpos($pattern, '*') !== false) {
+            if ($matchedPlatformPackage) {
+                $this->io->writeError('<warning>Pattern "' . $pattern . '" listed for update matches platform packages, but these cannot be updated by Composer.</warning>');
+            } elseif (strpos($pattern, '*') !== false) {
                 $this->io->writeError('<warning>Pattern "' . $pattern . '" listed for update does not match any locked packages.</warning>');
             } else {
                 $this->io->writeError('<warning>Package "' . $pattern . '" listed for update is not locked.</warning>');
