@@ -26,7 +26,7 @@ class TransportException extends \RuntimeException
     /** @var array<mixed> */
     protected $responseInfo = [];
 
-    public function __construct(string $message = "", int $code = 400, \Throwable $previous = null)
+    public function __construct(string $message = "", int $code = 400, ?\Throwable $previous = null)
     {
         parent::__construct($message, $code, $previous);
     }
