@@ -26,13 +26,13 @@ class XzDownloader extends ArchiveDownloader
 {
     protected function extract(PackageInterface $package, string $file, string $path): PromiseInterface
     {
-        $command = 'tar -xJf ' . ProcessExecutor::escape($file) . ' -C ' . ProcessExecutor::escape($path);
+        $command = ['tar', '-xJf', $file, '-C', $path];
 
         if (0 === $this->process->execute($command, $ignoredOutput)) {
             return \React\Promise\resolve(null);
         }
 
-        $processError = 'Failed to execute ' . $command . "\n\n" . $this->process->getErrorOutput();
+        $processError = 'Failed to execute ' . implode(' ', $command) . "\n\n" . $this->process->getErrorOutput();
 
         throw new \RuntimeException($processError);
     }
