@@ -20,4 +20,9 @@ final class IgnoreAllPlatformRequirementFilter implements PlatformRequirementFil
     {
         return PlatformRepository::isPlatformPackage($req);
     }
+
+    public function isUpperBoundIgnored(string $req): bool
+    {
+        return $this->isIgnored($req);
+    }
 }
