@@ -13,6 +13,7 @@
 namespace Composer\Util;
 
 use Composer\Pcre\Preg;
+use ErrorException;
 use React\Promise\PromiseInterface;
 use RecursiveDirectoryIterator;
 use RecursiveIteratorIterator;
@@ -108,9 +109,9 @@ class Filesystem
         }
 
         if (Platform::isWindows()) {
-            $cmd = sprintf('rmdir /S /Q %s', ProcessExecutor::escape(realpath($directory)));
+            $cmd = ['rmdir', '/S', '/Q', Platform::realpath($directory)];
         } else {
-            $cmd = sprintf('rm -rf %s', ProcessExecutor::escape($directory));
+            $cmd = ['rm', '-rf', $directory];
         }
 
         $result = $this->getProcess()->execute($cmd, $output) === 0;
@@ -143,9 +144,9 @@ class Filesystem
         }
 
         if (Platform::isWindows()) {
-            $cmd = sprintf('rmdir /S /Q %s', ProcessExecutor::escape(realpath($directory)));
+            $cmd = ['rmdir', '/S', '/Q', Platform::realpath($directory)];
         } else {
-            $cmd = sprintf('rm -rf %s', ProcessExecutor::escape($directory));
+            $cmd = ['rm', '-rf', $directory];
         }
 
         $promise = $this->getProcess()->executeAsync($cmd);
@@ -257,7 +258,21 @@ class Filesystem
             }
 
             if (!@mkdir($directory, 0777, true)) {
-                throw new \RuntimeException($directory.' does not exist and could not be created: '.(error_get_last()['message'] ?? ''));
+                $e = new \RuntimeException($directory.' does not exist and could not be created: '.(error_get_last()['message'] ?? ''));
+
+                // in pathological cases with paths like path/to/broken-symlink/../foo is_dir will fail to detect path/to/foo
+                // but normalizing the ../ away first makes it work so we attempt this just in case, and if it still fails we
+                // report the initial error we had with the original path, and ignore the normalized path exception
+                // see https://github.com/composer/composer/issues/11864
+                $normalized = $this->normalizePath($directory);
+                if ($normalized !== $directory) {
+                    try {
+                        $this->ensureDirectoryExists($normalized);
+                        return;
+                    } catch (\Throwable $ignoredEx) {}
+                }
+
+                throw $e;
             }
         }
     }
@@ -349,8 +364,33 @@ class Filesystem
      */
     public function copy(string $source, string $target)
     {
+        // refs https://github.com/composer/composer/issues/11864
+        $target = $this->normalizePath($target);
+
         if (!is_dir($source)) {
-            return copy($source, $target);
+            try {
+                return copy($source, $target);
+            } catch (ErrorException $e) {
+                // if copy fails we attempt to copy it manually as this can help bypass issues with VirtualBox shared folders
+                // see https://github.com/composer/composer/issues/12057
+                if (str_contains($e->getMessage(), 'Bad address')) {
+                    $sourceHandle = fopen($source, 'r');
+                    $targetHandle = fopen($target, 'w');
+                    if (false === $sourceHandle || false === $targetHandle) {
+                        throw $e;
+                    }
+                    while (!feof($sourceHandle)) {
+                        if (false === fwrite($targetHandle, (string) fread($sourceHandle, 1024 * 1024))) {
+                            throw $e;
+                        }
+                    }
+                    fclose($sourceHandle);
+                    fclose($targetHandle);
+
+                    return true;
+                }
+                throw $e;
+            }
         }
 
         $it = new RecursiveDirectoryIterator($source, RecursiveDirectoryIterator::SKIP_DOTS);
@@ -387,8 +427,7 @@ class Filesystem
 
         if (Platform::isWindows()) {
             // Try to copy & delete - this is a workaround for random "Access denied" errors.
-            $command = sprintf('xcopy %s %s /E /I /Q /Y', ProcessExecutor::escape($source), ProcessExecutor::escape($target));
-            $result = $this->getProcess()->execute($command, $output);
+            $result = $this->getProcess()->execute(['xcopy', $source, $target, '/E', '/I', '/Q', '/Y'], $output);
 
             // clear stat cache because external processes aren't tracked by the php stat cache
             clearstatcache();
@@ -401,8 +440,7 @@ class Filesystem
         } else {
             // We do not use PHP's "rename" function here since it does not support
             // the case where $source, and $target are located on different partitions.
-            $command = sprintf('mv %s %s', ProcessExecutor::escape($source), ProcessExecutor::escape($target));
-            $result = $this->getProcess()->execute($command, $output);
+            $result = $this->getProcess()->execute(['mv', $source, $target], $output);
 
             // clear stat cache because external processes aren't tracked by the php stat cache
             clearstatcache();
@@ -419,10 +457,11 @@ class Filesystem
      * Returns the shortest path from $from to $to
      *
      * @param  bool                      $directories if true, the source/target are considered to be directories
+     * @param  bool                      $preferRelative if true, relative paths will be preferred even if longer
      * @throws \InvalidArgumentException
      * @return string
      */
-    public function findShortestPath(string $from, string $to, bool $directories = false)
+    public function findShortestPath(string $from, string $to, bool $directories = false, bool $preferRelative = false)
     {
         if (!$this->isAbsolutePath($from) || !$this->isAbsolutePath($to)) {
             throw new \InvalidArgumentException(sprintf('$from (%s) and $to (%s) must be absolute paths.', $from, $to));
@@ -454,7 +493,7 @@ class Filesystem
         $commonPathCode = str_repeat('../', $sourcePathDepth);
 
         // allow top level /foo & /bar dirs to be addressed relatively as this is common in Docker setups
-        if ('/' === $commonPath && $sourcePathDepth > 1) {
+        if (!$preferRelative && '/' === $commonPath && $sourcePathDepth > 1) {
             return $to;
         }
 
@@ -470,10 +509,11 @@ class Filesystem
      * Returns PHP code that, when executed in $from, will return the path to $to
      *
      * @param  bool                      $directories if true, the source/target are considered to be directories
+     * @param  bool                      $preferRelative if true, relative paths will be preferred even if longer
      * @throws \InvalidArgumentException
      * @return string
      */
-    public function findShortestPathCode(string $from, string $to, bool $directories = false, bool $staticCode = false)
+    public function findShortestPathCode(string $from, string $to, bool $directories = false, bool $staticCode = false, bool $preferRelative = false)
     {
         if (!$this->isAbsolutePath($from) || !$this->isAbsolutePath($to)) {
             throw new \InvalidArgumentException(sprintf('$from (%s) and $to (%s) must be absolute paths.', $from, $to));
@@ -503,7 +543,7 @@ class Filesystem
         $sourcePathDepth = substr_count((string) substr($from, \strlen($commonPath)), '/') + (int) $directories;
 
         // allow top level /foo & /bar dirs to be addressed relatively as this is common in Docker setups
-        if ('/' === $commonPath && $sourcePathDepth > 1) {
+        if (!$preferRelative && '/' === $commonPath && $sourcePathDepth > 1) {
             return var_export($to, true);
         }
 
@@ -591,7 +631,6 @@ class Filesystem
 
         // ensure c: is normalized to C:
         $prefix = Preg::replaceCallback('{(^|://)[a-z]:$}i', static function (array $m) {
-            assert(is_string($m[0]));
             return strtoupper($m[0]);
         }, $prefix);
 
@@ -621,7 +660,13 @@ class Filesystem
      */
     public static function isLocalPath(string $path)
     {
-        return Preg::isMatch('{^(file://(?!//)|/(?!/)|/?[a-z]:[\\\\/]|\.\.[\\\\/]|[a-z0-9_.-]+[\\\\/])}i', $path);
+        // on windows, \\foo indicates network paths so we exclude those from local paths, however it is unsafe
+        // on linux as file:////foo (which would be a network path \\foo on windows) will resolve to /foo which could be a local path
+        if (Platform::isWindows()) {
+            return Preg::isMatch('{^(file://(?!//)|/(?!/)|/?[a-z]:[\\\\/]|\.\.[\\\\/]|[a-z0-9_.-]+[\\\\/])}i', $path);
+        }
+
+        return Preg::isMatch('{^(file://|/|/?[a-z]:[\\\\/]|\.\.[\\\\/]|[a-z0-9_.-]+[\\\\/])}i', $path);
     }
 
     /**
@@ -794,11 +839,7 @@ class Filesystem
             @rmdir($junction);
         }
 
-        $cmd = sprintf(
-            'mklink /J %s %s',
-            ProcessExecutor::escape(str_replace('/', DIRECTORY_SEPARATOR, $junction)),
-            ProcessExecutor::escape(realpath($target))
-        );
+        $cmd = ['mklink', '/J', str_replace('/', DIRECTORY_SEPARATOR, $junction), Platform::realpath($target)];
         if ($this->getProcess()->execute($cmd, $output) !== 0) {
             throw new IOException(sprintf('Failed to create junction to "%s" at "%s".', $target, $junction), 0, null, $target);
         }
